home | help
DU(1)			     General Commands Manual			   DU(1)

NAME
     du -- display disk usage statistics

SYNOPSIS
     du [-A] [-H | -L | -P] [-a | -s | -d depth | -t threshold] [-c] [-l]
	[-h | -k | -m | -B blocksize] [-n] [-x] [-I mask] [file ...]

DESCRIPTION
     The  du utility displays the file system block usage for each file argument
     and for each directory in the file hierarchy rooted in each directory argu-
     ment.  If no file is specified, the block usage of the hierarchy rooted  in
     the current directory is displayed.

     The options are as follows:

     -A      Display  the  apparent size instead of the disk usage.  This can be
	     helpful when operating on compressed volumes or sparse files.

     -B blocksize
	     Calculate block counts in blocksize byte blocks.  This is different
	     from the -k, -m options or setting BLOCKSIZE and gives an	estimate
	     of  how  much  space  the examined file hierachy would require on a
	     filesystem with the given blocksize.  Unless in -A mode,  blocksize
	     is rounded up to the next multiple of 512.

     -H      Symbolic  links on the command line are followed, symbolic links in
	     file hierarchies are not followed.

     -L      Symbolic links on the command line and in file hierarchies are fol-
	     lowed.

     -I mask
	     Ignore files and directories matching the specified mask.

     -P      No symbolic links are followed.  This is the default.

     -a      Display an entry for each file in a file hierarchy.

     -h      "Human-readable"  output.	 Use  unit  suffixes:  Byte,   Kilobyte,
	     Megabyte, Gigabyte, Terabyte and Petabyte.

     -r      Generate messages about directories that cannot be read, files that
	     cannot  be  opened, and so on.  This is the default case.	This op-
	     tion exists solely for conformance with  X/Open  Portability  Guide
	     Issue 4 ("XPG4").

     -s      Display an entry for each specified file.	(Equivalent to -d 0)

     -t threshold
	     Display   only  entries  for  which  size	exceeds  threshold.   If
	     threshold is negative, display only entries for which size is  less
	     than the absolute value of threshold.

     -d depth
	     Display  an  entry  for all files and directories depth directories
	     deep.

     -c      Display a grand total.

     -k      Display block counts in 1024-byte (1-Kbyte) blocks.

     -l      If a file has multiple hard links, count its size many times.   The
	     default  behavior	of du is to count files with multiple hard links
	     only once.  When the -l option is specified, the hard  link  checks
	     are  disabled,  and these files are counted (and displayed) as many
	     times as they are found.

     -m      Display block counts in 1048576-byte (1-Mbyte) blocks.

     -n      Ignore files and directories with user  "nodump"  flag  (UF_NODUMP)
	     set.

     -x      File system mount points are not traversed.

     The  du utility counts the storage used by symbolic links and not the files
     they reference unless the -H or -L option is specified.  If either  the  -H
     or  -L  options are specified, storage used by any symbolic links which are
     followed is not counted or displayed.

ENVIRONMENT
     BLOCKSIZE	If the environment variable BLOCKSIZE is set, and the -k, -m  or
		-h options are not specified, the block counts will be displayed
		in  units  of that block size.	If BLOCKSIZE is not set, and the
		-k, -m or -h options are not specified, the block counts will be
		displayed in 512-byte blocks.

SEE ALSO
     df(1), chflags(2), fts(3), symlink(7), quot(8)

HISTORY
     A du command appeared in Version 1 AT&T UNIX.

FreeBSD 8.2			November 6, 2008			   DU(1)

home | help